#!/bin/sh
#
# This script prints output for "rlm status" command.

. /usr/local/bin/sig_catcher

config=/tmp/eth0
config6=/tmp/eth0_6

ifconfig eth0 > $config
/sbin/ip -6 addr > $config6

MAC=`awk '/HWaddr/ { print $5}' $config`
IP=`awk '/inet addr/ {split($2, a, ":"); print a[2]}' $config`
MASK=`awk '/Mask/ {split($4, a, ":"); print a[2]}' $config`
GW=`route -n | awk '{if ($1 == "0.0.0.0") print $2}'`

LINK=`awk '/scope link/ {split($2, a, "/"); print a[1]}' $config6`
LINK_PFX=`awk '/scope link/ {split($2, a, "/"); print a[2]}' $config6`
ROUTER=`awk '/scope global dynamic $/ {split($2, a, "/"); print a[1]}' $config6`
ROUTER_PFX=`awk '/scope global dynamic $/ {split($2, a, "/"); print a[2]}' $config6`

ipv6_ga=$(ip -o -6 addr show dev eth0 scope global | grep -v "dynamic" | sed 's/  */ /g' | cut -d' ' -f 4 | head -1)
if [ -n "$ipv6_ga" ] ; then
    GLOBAL="${ipv6_ga%/*}"
    GLOBAL_PFX="${ipv6_ga#*/}"
fi

# here's the deal: depending on what the router advertises, 
# it's possible to have a default route that expires, this OK in terms of ipv6, but the existing
# code here wanted default routes with no expiration date.
# This code will look for an non-expiring default route first (like the prior configuration).  
# If that's not found it will look at the configuration file rlm_config_from_filer and get the default route 
# and see if it matches what was requested.
GLOBAL_GW=$(ip -6 route show dev eth0 | grep ^default | grep -v expires | cut -d ' ' -f 3)
if [ -z "$GLOBAL_GW" ] ; then
    config_gateway="$(grep ^ip6_gate /mnt/logs/etc/rlm_config_from_filer | cut -f 2 -d' ')"
    if [ -n "${config_gateway}" ] ; then 
        if ! ip -6 route show dev eth0 | grep ^default | grep "${config_gateway}" 2>&1 /dev/null ; then
            GLOBAL_GW="${config_gateway}"
        fi
    fi
fi

rm -f $config $config6

echo "Firmware Version:    " `/usr/local/bin/version.sh -e -r`
echo "Mgmt MAC Address:     $MAC"
echo "Ethernet Link:       " `/usr/local/bin/switch link 1 1 | sed 's|.*Link : *||'`

if [ "$IP" = "" ] && [ "$MASK" = "" ] && [ "$GW" = "" ]; then
	echo "IPv4 configuration:   Disabled"
else
	if [ -f /var/run/udhcpc.eth0.pid ]; then
		echo "  Using DHCP:         yes"
	else
		echo "  Using DHCP:         no"
	fi
	echo "IPv4 configuration:"
	echo "  IP Address:         $IP"
	echo "  Netmask:            $MASK"
	echo "  Gateway:            $GW"
fi

if [ "$GLOBAL" = "" ] && [ "$ROUTER" = "" ] && [ "$LINK" = "" ]; then
	echo "IPv6 configuration:   Disabled"
else
	echo "IPv6 configuration:"

	if [ "$GLOBAL" = "" ]; then
		echo "  Global IP:          Disabled"
	else
		echo "  Global IP:          $GLOBAL"
		echo "  Prefix Length:      $GLOBAL_PFX"
		echo "  Gateway Address:    $GLOBAL_GW"
	fi

	if [ "$ROUTER" = "" ]; then
		echo "  Router Assigned IP: Disabled"
	else
		echo "  Router IP:          $ROUTER"
		echo "  Prefix Length:      $ROUTER_PFX"
	fi

	if [ "$LINK" = "" ]; then
		echo "  Link Local IP:      Disabled"
	else
		echo "  Link Local IP:      $LINK"
		echo "  Prefix Length:      $LINK_PFX"
	fi
fi

if test $1 ; then 
    if [ "$1" = "-v" ] ; then 
	rlm_stats -p
    else if [ "$1" = "-d" ] ; then 
	    debug.sh
	 fi
    fi
fi
